#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
#
# File:            sourceDeCONZ.py
#
# License:         Donationware, see attached LICENSE file for more
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.8b
#
# Date:            23.01.2024
#
# Description:     TaloLogger configuration wrapper for deCONZ REST-API.
#
# Version history: ** 23.01.2024 v1.8b (Olli Lammi) **
#                  Initial version.
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import deCONZRESTAPI


###########################################################################

# Classes

class DeCONZRESTAPIConf(deCONZRESTAPI.DeCONZRESTAPI, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        deCONZRESTAPI.DeCONZRESTAPI.__init__(self)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runQueryCommand(cmds)

    def handleConfiguration(self, conf):
        self.url = conf.getValue('URL', '', self.getModuleName())
        self.apikey = conf.getValue('APIKEY', '', self.getModuleName())
        return (1, '')

    def initConfiguration(self):
        if len(self.url) <= 0:
            return (-1, 'Missing deCONZ REST-API URL.')

        if len(self.apikey) <= 0:
            return (-1, 'Missing deCONZ APIKEY.')

        if not self.initAPI():
            return (0, 'Error initializing deCONZ REST-API.')

        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'DECONZ'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['URL', 'APIKEY'], [])
