#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
#
# File:            sourceHomeWizard.py
#
# License:         Donationware, see attached LICENSE file for more
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.8c
#
# Date:            30.01.2024
#
# Description:     TaloLogger configuration wrapper for
#                  HomeWizard Energy API.
#
# Version history: ** 30.01.2024 v1.8c (Olli Lammi) **
#                  Initial version.
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import homeWizardAPI


###########################################################################

# Classes

class HomeWizardAPIConf(homeWizardAPI.HomeWizardAPI, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        homeWizardAPI.HomeWizardAPI.__init__(self)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runQueryCommand(cmds)

    def handleConfiguration(self, conf):
        self.url = conf.getValue('URL', '', self.getModuleName())
        return (1, '')

    def initConfiguration(self):
        if len(self.url) <= 0:
            return (-1, 'Missing HomeWizard Energy API URL.')

        if not self.initAPI():
            return (0, 'Error initializing HomeWizard Energy API.')

        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'HOMEWIZARD'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['URL'], [])
