#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            shellSource.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0d
#
# Date:            01.02.2015
#
# Description:     Library to use a script or executable as a data source.
#                  Result is validated and parsed using regexp.
#                  
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.3)
#
# Version history: ** 07.11.2011 v1.0a (Olli Lammi) **
#                  First version. 
#
#                  ** 07.11.2011 v1.0a (Olli Lammi) **
#                  Multi support. 
#
#                  ** 02.12.2014 v1.0c (Olli Lammi) **
#                  Changed from re matching to searching. Changed
#                  to DOTALL.
#
#                  ** 01.02.2015 v1.0d (Olli Lammi) **
#                  Support for multiple regular expressions.
#
###########################################################################

# Imports

import sys, os 
import string, subprocess
import re

from modules.core import log
from modules.utils import utils


###########################################################################

# Constants


###########################################################################

# Classes

class ShellSource(log.Logging):
    def __init__(self, shbin, shparam, shregexp):
        log.Logging.__init__(self, 'ShellSource')
        self.SH_BINARY = shbin
        self.SH_PARAM = shparam
        self.SH_REGEXP = shregexp
        self.timeout = 0

    def setTimeout(self, tout):
        self.timeout = tout

    def runQueryCommand(self, cmds):
        dataresult = {}
        shcmd = self.SH_BINARY + ' ' + self.SH_PARAM

        self.Debug("Executing command: " + shcmd)
        
        tocmd = utils.TimeoutableShellCommand()
        tocmd.setTimeout(self.timeout)
        (stat, outstdout, outstderr) = tocmd.execute(shcmd)
        
        if stat != 0:
            temps = "ERROR: Error executing Shell data source command\n"
            temps = temps + "  Command: " + shcmd + "\n"
            temps = temps + "  Command output: " + outstdout + outstderr
            temps = temps + "\n  Command status: %d" % stat
            self.Log(temps)                
            data = ""
        else:
            data = string.strip(outstdout)
        self.Debug("Received shell command data: " + repr(data))

        if len(data) <= 0:
            return {}
        
        for regstr in self.SH_REGEXP:
            try:
                result = re.search(regstr, data, re.DOTALL)
            except:
                self.Log("ERROR: Invalid regular expression: " + regstr)
                continue
            
            if result == None:
                self.Log("ERROR: Shell data does not match (regexp: %s): %s" % (regstr, data))
                continue
            
            for cmd in cmds:
                if cmd in result.groupdict().keys():
                    dataresult[cmd] = result.group(cmd)
                
        return dataresult
