#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceSmartWeb.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.4i
#
# Date:            13.02.2012
#
# Description:     TaloLogger configuration wrapper for SmartWeb library.
#                  
# Version history: ** 11.10.2011 v1.4e (Olli Lammi) **
#                  Moved from main taloLogger application module. 
#
#                  ** 13.02.2012 v1.4i (Olli Lammi) **
#                  Multisupport
#
###########################################################################

# Imports

import string

from modules.core import configuration
from modules.core import dataSource

import smartWeb


###########################################################################

# Classes

class SmartWebConf(smartWeb.SmartWeb, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        smartWeb.SmartWeb.__init__(self)
        dataSource.DataSource.__init__(self)        
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runDataSourceQueryMultiWrapper(cmds)

    def handleConfiguration(self, conf):
        self.url = conf.getValue('URL', '', self.getModuleName())
        self.user = conf.getValue('USER', '', self.getModuleName())
        self.password = conf.getValue('PASSWORD', '', self.getModuleName())
        self.setIds(self.handleSmartWebConf(conf))
        return (1, '')

    def handleSmartWebConf(self, conf):
        idmap = {}
        for item in conf.getValue('ITEMID', [], self.getModuleName()):
            temps = string.split(item, ':', 2)
            if len(temps) < 2:
                self.log("ERROR: Invalid ITEMID configuration: " + item)
            else:
                try:
                    key = string.strip(temps[0])
                    itemid = int(string.strip(temps[1]))
                except:
                    key = ''
                if len(key) <= 0:
                    self.log("ERROR: Invalid ITEMID configuration: " + item)
                else:
                    idmap[key] = itemid
        return idmap
        
    def initConfiguration(self):
        if len(self.url) <= 0:
            return (-1, 'Missing SmartWeb URL.')
        if len(self.user) <= 0:
            return (-1, 'Missing SmartWeb user name.')
        if len(self.password) <= 0:
            return (-1, 'Missing SmartWeb password.')

        if self.authenticate():
            self.Log('Authenticated to SmartWeb (session id %s).' % (self.sessionId,))
        else:
            return (0, 'Error authenticating to SmartWeb.')
            
        if len(self.ids.keys()) <= 0:
            return (0, 'No item IDs configured for SmartWeb datasource module.')
        
        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'SMARTWEB'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['URL', 'USER', 'PASSWORD'], ['ITEMID'])

